==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/thread_lookup.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="threadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">IPアドレス(及び固有識別番号)の検索</a>
</div>

<h1>IPアドレス(及び固有識別番号)の検索</h1>

<?cs if:Code0 ?>
<?cs if:Done_thread_lookup ?><div class="" id="notify"></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
});
function lookup( ip, element, event ) {
    Zeromin2.lookup(
        jQuery("form#threadsContainerForm").get(0), ip, element, event );
}
//]]>
</script>

<p>
IPアドレス(及び固有識別番号)の検索をします。
</p>
<p>
<ul>
<li>現在アドレスが<strong><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(Target) ?>', this, event )"><?cs var:html_escape(Target) ?></a></strong>と一致する投稿記録を表示中です。</li>
<li>「スレッド名」のリンクをクリックすると「レス番号」の投稿内容に移動します。</li>
</ul>
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
    <tr><td>スレッド名</td><td>レス番号</td><td>時刻</td><td>ブラウザ情報</td></tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
    <tr><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(item.key) ?>&amp;option=<?cs var:html_escape(item.resno) ?>n&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.subject) ?></a></td><td><?cs var:html_escape(item.resno) ?></td><td><code><?cs var:html_escape(item.date) ?></code></td><td><?cs var:html_escape(item.agent) ?></td></tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="thread" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="target" value="<?cs var:html_escape(Target) ?>" />
<input type="hidden" name="OK" value="lookup" />
<input type="hidden" name="NG" value="lookup" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.0.1.tar.bz2: img0ch/_template/zeromin2/thread_lookup.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="threadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">IPアドレス(及び固有識別番号)の検索</a>
</div>

<h1>IPアドレス(及び固有識別番号)の検索</h1>

<?cs if:Code0 ?>
<?cs if:Done_thread_lookup ?><div class="" id="notify"></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
});
function lookup( ip, element, event ) {
    Zeromin2.lookup(
        jQuery("#threadsContainerForm").get(0), ip, element, event );
}
//]]>
</script>

<p>
IPアドレス(及び固有識別番号)の検索をします。
</p>
<p>
<ul>
<li>現在アドレスが<strong><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(Target) ?>', this, event )"><?cs var:html_escape(Target) ?></a></strong>と一致する投稿記録を表示中です。</li>
<li>「スレッド名」のリンクをクリックすると「レス番号」の投稿内容に移動します。</li>
</ul>
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(Target) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
    <tr><td>スレッド名</td><td>レス番号</td><td>時刻</td><td>ブラウザ情報</td></tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
    <tr><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(item.key) ?>&amp;option=<?cs var:html_escape(item.resno) ?>n&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.subject) ?></a></td><td><?cs var:html_escape(item.resno) ?></td><td><code><?cs var:html_escape(item.date) ?></code></td><td><?cs var:html_escape(item.agent) ?></td></tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="thread" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="target" value="<?cs var:html_escape(Target) ?>" />
<input type="hidden" name="OK" value="lookup" />
<input type="hidden" name="NG" value="lookup" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
